# Errors

- issue parsing Drug Gene Interaction Database: 
- failed to resolve Antibody Registry
- issue parsing Ensembl: Issue in EnsemblGetter with date July 2023 and fmt %b %Y
- failed to resolve National Cancer Institute Thesaurus